/**
 * @brief		User Application: Autonomous Tracker
 */

#include "Application.API.h"

#include "FSM_Tracking.h"
#include "FSM_Radio.h"
#include "FSM_Acc.h"

#include "Application.h"

APP(__APP_NAME, __APPVER_MAJOR, __APPVER_MINOR);


void Application_Init() {
	if (Init_Success != MATAKI_InitDriversNoSCP()) {
		// stop the device
		MATAKI_CriticalLPM4(1);
	}
	
	LIGHT_DISABLE;

	
	//log Power On Reset event
	logentry_t entry;
	LogEngine_PrepareLogEntry(&entry);
	entry.TypeId = POR;
	LogEngine_Save(&entry);

	// this is reached when the node id differs, do a remote print to all nodes around
	LOGREMOTE("tracker online! (1)");
	LOGREMOTE("tracker online! (2)");
	LOGREMOTE("tracker online! (3)");
	
	// initialize state machines
	FSM_Tracking_Init();
	FSM_Radio_Init();
	FSM_Acc_Init();

	LOGATT("Use the 'abort' command to abort the experiment!");
}

COMMAND(abort, "Aborts the experiment", args) {
	//printf("\033[2J\033[H"); ///< this clears the screen and puts the cursor in the upper left corner.
	// abort the state machines
	FSM_Tracking_Abort();
	FSM_Radio_Abort();
	FSM_Acc_Abort();
}


COMMAND(f_reset, "Formats and resets the device", args) {
	printf("format + reset\r\n");

	LOGREMOTE("Formatting and restarting the device... (1)");
	LOGREMOTE("Formatting and restarting the device... (2)");
	LOGREMOTE("Formatting and restarting the device... (3)");
	
	Flash_Erase(); 								// format (format just exits without waiting for success.
	Flash_WaitForDeviceWithVisualFeedback();
	
	// and reset the device
	Watchdog_DeviceReset();
}



#ifndef DOXYGEN_PUBLIC_DOC
/**
* Copyright (c) Microsoft Corporation. All rights reserved.
* Licensed under the Apache License, Version 2.0 (the "License"); you may not use these files except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
* Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 
* Copyright (c) 2012 Freie Universitaet Berlin, Tomasz Naumowicz. All rights reserved.
* 
* Redistribution and use in source and binary forms, with or without modification, are
* permitted provided that the following conditions are met:
* 
* - Redistributions of source code must retain the above copyright notice, this list of
* conditions and the following disclaimer.
* 
* - Redistributions in binary form must reproduce the above copyright notice, this list
* of conditions and the following disclaimer in the documentation and/or other materials
* provided with the distribution.
* 
* - Neither the name of the Freie Universitaet Berlin nor the
* names of its contributors may be used to endorse or promote products
* derived from this software without specific prior written permission.
* 
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
* DISCLAIMED. IN NO EVENT SHALL Freie Universitaet Berlin BE LIABLE FOR ANY
* DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
* (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#endif // DOXYGEN
