/**
 * @file		FSM_Acc.h
 * @brief		State machine controling the accelerometer sensor.
 * The Accelerometer Finite State Machine controls the hevahior of the Accelerometer.
 */

#ifndef FSM_ACC_H_
#define FSM_ACC_H_

#include "Application.API.h"

/**
 * Starts the Accelerometer measurement state machine.
 * 
 * The behavior of the state machine:
 * 
 * @dot
 * digraph fsm {
 * 		graph 					[fontname=Helvetica, fontsize=10];
 * 		edge 					[fontname=Helvetica, fontsize=10];
 *
 *  
 *		node 					[shape=circle, fontname=Helvetica, fontsize=10];
 * 		idle 					[label = "Idle\nGPS Disabled", color="darkgreen", style="filled", fillcolor="lightgrey"];
 *		waiting 				[label = "Waiting for a Fix\nGPS Enabled"];
 * 		logging 				[label = "Logging Position\nGPS Enabled"]
 *
 * 		idle -> measurement		[label="Configurable Timeout\n(Enable ACC)", style="dashed", weight="8", color="darkgreen", fontcolor="blue"];
 * 		measurement -> idle 	[label="Configurable Timeout\n(Disable ACC)", style="dashed", weight="8", fontcolor="blue"];
 *		node 					[shape=circle, fontname=Helvetica, fontsize=10, color="gray", fontcolor="gray"];
 * 		suspend 				[label = "ACC Disabled"];
 * 
 * }
 * @enddot
 */
void FSM_Acc_Init();

void FSM_Acc_Abort();

uint8_t	FSM_Acc_LastX;
uint8_t	FSM_Acc_LastY;
uint8_t	FSM_Acc_LastZ;

void FSM_Acc_Suspend();

#endif /*FSM_Acc_H_*/

#ifndef DOXYGEN_PUBLIC_DOC
/**
* Copyright (c) Microsoft Corporation. All rights reserved.
* Licensed under the Apache License, Version 2.0 (the "License"); you may not use these files except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
* Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
*/
#endif // DOXYGEN
