/**
 * @file		CMA3000.h
 * @ingroup		Driver
 * @brief		@b Driver: CMA Accelerometer sensor
 * 
 *  
 * This is only a simple driver for the CMA3000 sensor. The only feature of this driver is the ability of disabling the I2C bus support
 * of the CMA3000 sensor. This is required as both, the support for SPI and I2C bus, are enabled per default. This can lead to issues
 * when communicating with other devices that share the same SPI bus.
 * That's why the first step prior to the SPI communication with other devices is disabling of the I2C bus of the CMA3000 sensor.
 * Support for other features of the CMA3000 sensor is currently not implemented.
 * 
 * @remarks To driver devlopers: SCL frequency max is 500kHz.
 */

#ifndef CMA3000_H_
#define CMA3000_H_

#define CMA_CS_POUT		CMA_CS_OUT //when high, device is deselected
#define CMA_CS_PDIR		CMA_CS_DIR
#define CMA_CS_PIN		CMA_nCS_PIN

//#define CMA_INT_PIN		CMA_INT_PIN
#define CMA_INT_POUT    CMA_INT_OUT
#define CMA_INT_PDIR    CMA_INT_DIR

#define CMA_SELECT		CLEAR(CMA_CS_POUT, CMA_CS_PIN)
#define CMA_DESELECT	SET(CMA_CS_POUT, CMA_CS_PIN)

/**
 * The driver for the CMA3000 device currently supports the enabling / disabling of the SPI/I2C bus feature,
 * reading and writing into an addressed register, this includes setting the sensor up for 
 * several measurement modes or power down
 */

void CMA3000_Write(uint8_t address, uint8_t data);
uint8_t CMA3000_Read(uint8_t address);

#endif /*CMA3000_H_*/

#ifndef DOXYGEN_PUBLIC_DOC
/**
* Copyright (c) Microsoft Corporation. All rights reserved.
* Licensed under the Apache License, Version 2.0 (the "License"); you may not use these files except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
* Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
*/
#endif // DOXYGEN
