/**
 * @file		InterfaceBoard.h
 * @ingroup		DriverAPI
 * @brief		@b Driver: Support for the MATAKI V4 interface board (used by Applications, Drivers and System)
 */

#ifndef INTERFACEBOARD_H_
#define INTERFACEBOARD_H_

/**
 * @brief Initializes the driver of the interface board.
 */
void InterfaceBoard_Init();

/**
 * @brief Turns on the selected LED within the LED block on the support board.
 * 
 * @param[in]	bit			The LED to be turned on, selcted by a single bit (BIT0-BIT7) or a bitmask
 */
void InterfaceBoard_LED_Set(uint8_t bit);

/**
 * @brief Turns off the selected LED within the LED block on the support board.
 * 
 * @param[in]	bit			The LED to be turned off, selcted by a single bit (BIT0-BIT7) or a bitmask
 */
void InterfaceBoard_LED_Clear(uint8_t bit);

/**
 * @brief Call to this function results in a short blink of the LED block. The state of the LED block doesn't change after the function returs.
 */
void InterfaceBoard_LED_Blink();

#endif /*INTERFACEBOARD_H_*/

/**
* Copyright (c) Microsoft Corporation. All rights reserved.
* Licensed under the Apache License, Version 2.0 (the "License"); you may not use these files except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
* Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 
* Copyright (c) 2012 Freie Universitaet Berlin, Tomasz Naumowicz. All rights reserved.
* 
* Redistribution and use in source and binary forms, with or without modification, are
* permitted provided that the following conditions are met:
* 
* - Redistributions of source code must retain the above copyright notice, this list of
* conditions and the following disclaimer.
* 
* - Redistributions in binary form must reproduce the above copyright notice, this list
* of conditions and the following disclaimer in the documentation and/or other materials
* provided with the distribution.
* 
* - Neither the name of the Freie Universitaet Berlin nor the
* names of its contributors may be used to endorse or promote products
* derived from this software without specific prior written permission.
* 
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
* ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
* DISCLAIMED. IN NO EVENT SHALL Freie Universitaet Berlin BE LIABLE FOR ANY
* DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
* (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/